@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: __init__.py 987 2009-01-31 16:38:00Z mac $
+# $Id: __init__.py 1282 2009-09-26 15:35:58Z mac $
 
-def truncate(text, length):
+def truncate(text, length, ellipsis='...'):
     if text is None:
         text = ''
     if not isinstance(text, basestring):
@@ -19,6 +19,6 @@ def truncate(text, length):
         pos = length + content[length:].find(' ')
         if pos != (len(content) - 1):
             # if the found whitespace is not the last one add an ellipsis
-            text = text[:pos].strip() + ' ...'
+            text = text[:pos].strip() + ' ' + ellipsis
 
     return text
